/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
/*
 * This header file has got all  the functions relative to the status of
 * the mobile phone.
 */
 
#ifndef _STATUS_H_
#define _STATUS_H_

#include <myericsson/command.h>

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

/*
 * Returns some information text to indentify the manufactorer.
 * 
 * @param device The FILE pointer associated to the device.
 * @param  response The  struct associated  with the  response from  the
 * mobile.
 */
void getManufactorerIdentification (FILE *device, response_t *response) ;

/*
 * Returns some information text to indentify the model type and name.
 * 
 * @param device The FILE pointer associated to the device.
 * @param  response The  struct associated  with the  response from  the
 * mobile.
 */
void getModelIdentification (FILE *device, response_t *response) ;

/*
 * Returns some information text to indentify the software's version.
 *
 * @param device The FILE pointer associated to the device.
 * @param  response The  struct associated  with the  response from  the
 * mobile.
 */
void getRevisionIdentification (FILE *device, response_t *response) ;

/*
 * Returns some information text to indentify the serial number.
 *
 * @param device The FILE pointer associated to the device.
 * @param  response The  struct associated  with the  response from  the
 * mobile.
 */
void getSerialNumberIndentification (FILE *device, response_t *response) ;

/*
 * Returns asome information about the basstery state.
 *
 * @param device The FILE pointer associated to the device.
 * @param  response The  struct associated  with the  response from  the
 * mobile.
 * @returns response->data contains one of the following values:
 * 0 : ME powered by the battery
 * 1 : ME has battery connected, but it's powered by the charger
 * 2 : ME doesn't have a battery connected
 */
void batteryStatus (FILE *device, response_t *response) ;

/*
 * Returns an int representing the per cent value of the charge.
 *
 * @param device The FILE pointer associated to the device.
 * @param  response The  struct associated  with the  response from  the
 * mobile.
 * @returns response->data contains the charge percent.
 */
void batteryCharge (FILE *device, response_t *response) ;

/*
 * Gets the power of the signal.
 *
 * @param device The FILE pointer associated to the device.
 * @param  response The  struct associated  with the  response from  the
 * mobile.
 * @return response->data contains one of the following values:
 * 0 : -113 dBm or less
 * 1 : -111 dBm
 * 2-30: -109 to -53 dBm
 * 31: -51 dBm or greater
 * 99: not known or not detectable
 */
void getRecievedPower (FILE *device, response_t *response) ;

/*
 * Gets the channel bit error rate.
 *
 * @param device The FILE pointer associated to the device.
 * @param  response The  struct associated  with the  response from  the
 * mobile.
 * @return response->data contains one of the following values:
 * 0-7 : EXQUAL values
 * 99 : not known or not detectable
 */
void getChannelBitErrorRate (FILE *device, response_t *response) ;

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* _STATUS_H_ */
